@@ -33,14 +33,14 @@ class Persister(object):
         self._batch_size = kafka_conf.batch_size
 
         self._consumer = consumer.KafkaConsumer(
-                kafka_conf.uri,
-                zookeeper_conf.uri,
-                kafka_conf.zookeeper_path,
-                kafka_conf.group_id,
-                kafka_conf.topic,
-                repartition_callback=self._flush,
-                commit_callback=self._flush,
-                commit_timeout=kafka_conf.max_wait_time_seconds)
+            kafka_conf.uri,
+            zookeeper_conf.uri,
+            kafka_conf.zookeeper_path,
+            kafka_conf.group_id,
+            kafka_conf.topic,
+            repartition_callback=self._flush,
+            commit_callback=self._flush,
+            commit_timeout=kafka_conf.max_wait_time_seconds)
 
         self.repository = repository()
 
@@ -52,15 +52,13 @@ class Persister(object):
             self.repository.write_batch(self._data_points)
 
             LOG.info("Processed {} messages from topic '{}'".format(
-                    len(self._data_points), self._kafka_topic))
+                len(self._data_points), self._kafka_topic))
 
             self._data_points = []
             self._consumer.commit()
         except Exception as ex:
-            if "partial write: points beyond retention policy dropped" in ex.message:
-                LOG.warning("Some points older than retention policy were dropped")
-                self._data_points = []
-                self._consumer.commit()
+            if ex.message.startswith("400: partial write: points beyond retention policy dropped"):
+                LOG.info("Some points older than retention policy were dropped")
             else:
                 LOG.exception("Error writing to database: {}"
                               .format(self._data_points))
@@ -81,7 +79,7 @@ class Persister(object):
                     self._flush()
         except Exception:
             LOG.exception(
-                    'Persister encountered fatal exception processing '
-                    'messages. '
-                    'Shutting down all threads and exiting')
+                'Persister encountered fatal exception processing '
+                'messages. '
+                'Shutting down all threads and exiting')
             os._exit(1)
